@@ -12,7 +12,7 @@ use warnings;
 
 package Dist::Zilla::Plugin::Git::Tag;
 BEGIN {
-  $Dist::Zilla::Plugin::Git::Tag::VERSION = '1.102810';
+  $Dist::Zilla::Plugin::Git::Tag::VERSION = '1.103470';
 }
 # ABSTRACT: tag the new version
 
@@ -24,10 +24,13 @@ use String::Formatter method_stringf => {
   -as => '_format_tag',
   codes => {
     d => sub { require DateTime;
-               DateTime->now->format_cldr($_[1] || 'dd-MMM-yyyy') },
+               DateTime->now(time_zone => $_[0]->time_zone)
+                       ->format_cldr($_[1] || 'dd-MMM-yyyy') },
     n => sub { "\n" },
-    N => sub { $_[0]->name },
-    v => sub { $_[0]->version },
+    N => sub { $_[0]->zilla->name },
+    t => sub { $_[0]->zilla->is_trial
+                 ? (defined $_[1] ? $_[1] : '-TRIAL') : '' },
+    v => sub { $_[0]->zilla->version },
   },
 };
 
@@ -39,6 +42,7 @@ with 'Dist::Zilla::Role::AfterRelease';
 
 has tag_format  => ( ro, isa=>Str, default => 'v%v' );
 has tag_message => ( ro, isa=>Str, default => 'v%v' );
+has time_zone   => ( ro, isa=>Str, default => 'local' );
 has branch => ( ro, isa=>Str, predicate=>'has_branch' );
 
 
@@ -47,7 +51,7 @@ has tag => ( ro, isa => Str, lazy_build => 1, );
 sub _build_tag
 {
     my $self = shift;
-    return _format_tag($self->tag_format, $self->zilla);
+    return _format_tag($self->tag_format, $self);
 }
 
 
@@ -69,7 +73,7 @@ sub after_release {
 
     # Make an annotated tag if tag_message, lightweight tag otherwise:
     my @opts = $self->tag_message
-        ? ( '-m' => _format_tag($self->tag_message, $self->zilla) )
+        ? ( '-m' => _format_tag($self->tag_message, $self) )
         : ();
     my @branch = $self->has_branch ? ( $self->branch ) : ();
 
@@ -90,7 +94,7 @@ Dist::Zilla::Plugin::Git::Tag - tag the new version
 
 =head1 VERSION
 
-version 1.102810
+version 1.103470
 
 =head1 SYNOPSIS
 
@@ -125,6 +129,9 @@ C<Formatting options> below.
 see C<Formatting options> below. Use C<tag_message = > to create a
 lightweight tag.
 
+=item * time_zone - the time zone to use with C<%d>.  Can be any
+time zone name accepted by DateTime.  Defaults to C<local>.
+
 =item * branch - which branch to tag. Defaults to current branch.
 
 =back
@@ -149,6 +156,11 @@ A newline
 
 The distribution name
 
+=item C<%{-TRIAL}t>
+
+Expands to -TRIAL (or any other supplied string) if this is a trial
+release, or the empty string if not.  A bare C<%t> means C<%{-TRIAL}t>.
+
 =item C<%v>
 
 The distribution version
